@@ -400,8 +400,8 @@ class Graph(abc.ABC):
         self._on_task_renamed.send(self, oldname=oldname, newname=newname)
 
 
-    def set_expression(self, name, expression, locals={}):
-        """Create a task that will execute a Python expression.
+    def set_expression(self, name, expression, symbols=None):
+        """Create a task that evaluates a Python expression, returning its value.
 
         The task will automatically track implicit dependencies that
         arise from executing the expression.
@@ -411,12 +411,15 @@ class Graph(abc.ABC):
         name: hashable object, required
             Unique name for the new expression task.
         expression: string, required
-            Python expression that will be executed whenever the task is executed.
-        locals: dict, optional
-            Optional dictionary containing local objects that will be available for
-            use in the expression.
+            Python expression that will be evaluated whenever the task is executed.
+        symbols: callable, optional
+            Function that returns a Python dict containing symbols that will be
+            available to the expression when it's executed.  If :any:`None` (the
+            default), the :func:`graphcat.common.builtins` function will be used, which gives the
+            expression access to `graph`, `name`, `inputs`, and `extent` objects
+            that match the arguments to a normal task function.
         """
-        fn = graphcat.common.execute(expression, locals)
+        fn = graphcat.common.evaluate(expression, symbols)
         fn = graphcat.common.automatic_dependencies(fn)
         self.set_task(name, fn)
 
